@@ -14,7 +14,7 @@ cat(paste("--------- Executing",
           "test code -----------\n"))
 #'  tests/randoms.R
 #'   Further tests of random generation code
-#'  $Revision: 1.18 $ $Date: 2024/02/26 05:43:36 $
+#'  $Revision: 1.20 $ $Date: 2025/04/07 03:54:43 $
 
 
 local({
@@ -60,6 +60,15 @@ local({
     Z <- rlabel(finpines)
   }
 
+  if(FULLTEST) {
+    ## intensity constant on each tile of a tessellation
+    X <- cells[c(2, 22, 32, 37)]
+    V <- dirichlet(X)
+    lam <- as.function(V, values=rep(5, nobjects(V)))
+    Y <- rpoispp(lam, tilewise=TRUE) # tilewise algorithm
+    Y <- rpoispp(lam) # code for default value of 'tilewise'
+  }
+  
   f1 <- function(x,y){(x^2 + y^3)/10}
   f2 <- function(x,y){(x^3 + y^2)/10}
   ZZ <- solist(A=as.im(f1, letterR),
@@ -140,6 +149,18 @@ local({
                     var = sigma2x, scale = range / sqrt(8), 
                     nu = 1, win = win)
   }
+  if(ALWAYS) {
+    #' rLGCP in window other than the unit square
+    ow <- owin(c(-3.75, 25.75), c(-3.75, 25.75))
+    X <- rLGCP(model = "exp", mu = -1.75, var = 1, scale = 2,
+               win = ow, saveLambda=TRUE, eps=0.5, rule.eps="shrink.frame")
+    if(FULLTEST) {
+      #' conditional simulation, same parameters
+      Y <- rLGCP(model = "exp", mu = -1.75, var = 1, scale = 2,
+                 win = ow, saveLambda=TRUE, eps=0.5, rule.eps="shrink.frame",
+                 n.cond=256)
+    }
+  }
 })
 
 reset.spatstat.options()
